vedis-python — vedis-python 0.1.2 documentation

### Navigation

- index
- next |
- vedis-python 0.1.2 documentation »

# vedis-python

Python bindings for Vedis, a fast, embedded, NoSQL database modeled after Redis.

The source code for vedis-python is hosted on GitHub.

Note

If you encounter any bugs in the library, please open an issue, including a description of the bug and any related traceback.

Contents:

- Installation
- Quickstart
  - Key/value features
  - Copying and Moving
  - Hashes
  - Sets
  - Lists
  - Misc

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- vedis-python 0.1.2 documentation »